==> nextcloud-15.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/de_DE.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Lade Vorschau…",
    "Saved" : "Gespeichert",
    "Admin" : "Administrator",
    "a safe home for all your data" : "Ein sicheres Zuhause für Ihre Daten",
    "Name cannot be empty" : "Der Name darf nicht leer sein",
    "The given name is too long" : "Der eingegebene Name ist zu lang",
    "The given web address is too long" : "Die eingegebene Adresse ist zu lang",
    "The given legal notice address is too long" : "Die im Impressum angegebene Adresse ist zu lang",
    "The given privacy policy address is too long" : "Die eingegebene Adresse der Datenschutzerklärung ist zu lang",
    "The given slogan is too long" : "Der eingegebene Slogan ist zu lang",
    "The given color is invalid" : "Die gewählte Farbe ist ungültig",
    "The file was uploaded" : "Die Datei wurde hochgeladen",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Die hochgeladene Datei überschreitet die upload_max_filesize-Vorgabe in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Die Datei ist größer, als die MAX_FILE_SIZE-Vorgabe erlaubt, die im HTML-Formular spezifiziert ist",
    "The file was only partially uploaded" : "Die Datei konnte nur teilweise hochgeladen werden",
    "No file was uploaded" : "Es wurde keine Datei hochgeladen",
    "Missing a temporary folder" : "Kein temporärer Ordner vorhanden",
    "Could not write file to disk" : "Die Datei konnte nicht auf die Festplatte geschrieben werden",
    "A PHP extension stopped the file upload" : "Eine PHP-Erweiterung hat das Hochladen der Datei gestoppt",
    "No file uploaded" : "Keine Datei hochgeladen",
    "Unsupported image type" : "Nicht unterstütztes Bild-Format",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Sie benutzen bereits ein benutzerdefiniertes Theme. Eine App für Themes würde dies überschreiben.",
    "Theming" : "Theming",
    "Legal notice" : "Impressum",
    "Privacy policy" : "Datenschutz",
    "Adjust the Nextcloud theme" : "Passe das Aussehen von Nextcloud an",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Theming ermöglicht es auf einfache Weise das Aussehen Ihrer Installation und Clients anzupassen. Die Änderungen wirken sich auf alle Benutzer aus.",
    "Name" : "Name",
    "Reset to default" : " Auf Standard zurücksetzen ",
    "Web link" : "Internetseite",
    "https://…" : "https://…",
    "Slogan" : "Slogan",
    "Color" : "Farbe",
    "Logo" : "Logo",
    "Upload new logo" : "Neues Logo hochladen",
    "Login image" : "Anmelde-Bild",
    "Upload new login background" : "Neuen Anmelde-Hintergrund hochladen",
    "Remove background image" : "Entferne Hintergrundbild",
    "Advanced options" : "Erweiterte Optionen",
    "Legal notice link" : "Link zu Impressum",
    "Privacy policy link" : "Link zur Datenschutzerklärung",
    "Header logo" : "Kopfbereich-Logo",
    "Upload new header logo" : "Neues Kopfbereich-Logo hochladen",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Neues Favicon hochladen",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Installieren Sie die Imagemagick PHP-Erweiterung mit Unterstützung für SVG-Bilder, um automatisch Favoriten-Icons auf Basis des hochgeladenen Icons und der Farbe zu erstellen.",
    "There is no error, the file uploaded with success" : "Es ist kein Fehler aufgetreten. Die Datei wurde erfolgreich hochgeladen.",
    "The uploaded file was only partially uploaded" : "Die Datei konnte nur teilweise übertragen werden",
    "Failed to write file to disk." : "Fehler beim Schreiben der Datei auf die Festplatte.",
    "A PHP extension stopped the file upload." : "Eine PHP-Erweiterung hat das Hochladen der Datei gestoppt.",
    "You are already using a custom theme" : "Sie benutzen bereits ein eigenes Thema",
    "Web address https://…" : "Internetadresse https://…"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/de_DE.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Lade Vorschau…",
    "Saved" : "Gespeichert",
    "Admin" : "Administrator",
    "a safe home for all your data" : "Ein sicheres Zuhause für Ihre Daten",
    "Name cannot be empty" : "Der Name darf nicht leer sein",
    "The given name is too long" : "Der eingegebene Name ist zu lang",
    "The given web address is too long" : "Die eingegebene Adresse ist zu lang",
    "The given legal notice address is too long" : "Die im Impressum angegebene Adresse ist zu lang",
    "The given privacy policy address is too long" : "Die eingegebene Adresse der Datenschutzerklärung ist zu lang",
    "The given slogan is too long" : "Der eingegebene Slogan ist zu lang",
    "The given color is invalid" : "Die gewählte Farbe ist ungültig",
    "The file was uploaded" : "Die Datei wurde hochgeladen",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Die hochgeladene Datei überschreitet die upload_max_filesize-Vorgabe in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Die Datei ist größer, als die MAX_FILE_SIZE-Vorgabe erlaubt, die im HTML-Formular spezifiziert ist",
    "The file was only partially uploaded" : "Die Datei konnte nur teilweise hochgeladen werden",
    "No file was uploaded" : "Es wurde keine Datei hochgeladen",
    "Missing a temporary folder" : "Kein temporärer Ordner vorhanden",
    "Could not write file to disk" : "Die Datei konnte nicht auf die Festplatte geschrieben werden",
    "A PHP extension stopped the file upload" : "Eine PHP-Erweiterung hat das Hochladen der Datei gestoppt",
    "No file uploaded" : "Keine Datei hochgeladen",
    "Unsupported image type" : "Nicht unterstütztes Bild-Format",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Sie benutzen bereits ein benutzerdefiniertes Design. Die App \"Theming\" würde dies überschreiben.",
    "Theming" : "Design",
    "Legal notice" : "Impressum",
    "Privacy policy" : "Datenschutz",
    "Adjust the Nextcloud theme" : "Passe das Design von Nextcloud an",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Das Ändern des Designs ermöglicht es auf einfache Weise das Aussehen Ihrer Installation und Clients anzupassen. Die Änderungen wirken sich auf alle Benutzer aus.",
    "Name" : "Name",
    "Reset to default" : " Auf Standard zurücksetzen ",
    "Web link" : "Internetseite",
    "https://…" : "https://…",
    "Slogan" : "Slogan",
    "Color" : "Farbe",
    "Logo" : "Logo",
    "Upload new logo" : "Neues Logo hochladen",
    "Login image" : "Anmeldebild",
    "Upload new login background" : "Neuen Anmelde-Hintergrund hochladen",
    "Remove background image" : "Entferne Hintergrundbild",
    "Advanced options" : "Erweiterte Optionen",
    "Legal notice link" : "Link zum Impressum",
    "Privacy policy link" : "Link zur Datenschutzerklärung",
    "Header logo" : "Kopfbereich-Logo",
    "Upload new header logo" : "Neues Kopfbereich-Logo hochladen",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Neues Favicon hochladen",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Installieren Sie die Imagemagick PHP-Erweiterung mit Unterstützung für SVG-Bilder, um automatisch Favoriten-Icons auf Basis des hochgeladenen Icons und der Farbe zu erstellen."
},
"nplurals=2; plural=(n != 1);");
